#### Please select the sections that you would like to print

Select All
Case Information
Party
Events and Hearings
Print

# Case Information

17-2-01460-31 | Griffis Group Residential vs Brandon Thompson **DISMISSED**

Case Number
17-2-01460-31

Court
Snohomish

File Date
02/17/2017

Case Type
UND Residential Unlawful Detainer

Case Status
Completed/Re-Completed

# Party

Plaintiff
Griffis Group Residential

Active Attorneys

Lead Attorney
NOVACK, LAUREN LESLIE

Retained

Attorney
REDFORD, RANDALL W

Retained

Attorney
WALSH, MICHAEL SEAN

Retained

Defendant
Thompson, Brandon

# Events and Hearings

- 02/17/2017 Summons

- 02/17/2017 Complaint

- 02/17/2017 Case Information Cover Sheet

- 02/17/2017 Statement

- 02/17/2017 Motion and Affidavit Declaration

  Comment
  Re Alternative Service

- 02/17/2017 Order Re Service

  Judicial Officer
  Gaer, Susan C

- 02/17/2017 Ex Parte Action With Order

- 02/13/2019 Clerks Notice for Dismissal for Want of Prosecution

- 04/03/2019 Clerks Order of Dismissal

  Judicial Officer
  Tinney, Lee B

  Comment
  ****************************************

- 04/03/2019 Ex Parte Action With Order

- 04/03/2019 Case Resolution Dismissal Closure by Clerk